==> win32_gamepad-1.0.5.tar.gz: example/inspector/lib/custom_window.dart <==
import 'package:bitsdojo_window/bitsdojo_window.dart';
import 'package:fluent_ui/fluent_ui.dart';

class CustomWindowTitleSection extends StatelessWidget {
  final String appTitle;

  const CustomWindowTitleSection({super.key, required this.appTitle});

  @override
  Widget build(BuildContext context) {
    return MoveWindow(
      child: Align(
        alignment: AlignmentDirectional.centerStart,
        child: Text(appTitle),
      ),
    );
  }
}

class CustomWindowButtonsSection extends StatelessWidget {
  const CustomWindowButtonsSection({
    super.key,
  });

  @override
  Widget build(BuildContext context) {
    return MoveWindow(
      child: const Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [Spacer(), WindowButtons()],
      ),
    );
  }
}

class WindowButtons extends StatelessWidget {
  const WindowButtons({super.key});

  @override
  Widget build(BuildContext context) {
    assert(debugCheckHasFluentTheme(context));
    assert(debugCheckHasFluentLocalizations(context));
    final theme = FluentTheme.of(context);
    final buttonColors = WindowButtonColors(
      iconNormal: theme.inactiveColor,
      iconMouseDown: theme.inactiveColor,
      iconMouseOver: theme.inactiveColor,
      mouseOver: ButtonThemeData.buttonColor(context, {ButtonStates.hovering}),
      mouseDown: ButtonThemeData.buttonColor(context, {ButtonStates.pressing}),
    );
    final closeButtonColors = WindowButtonColors(
      mouseOver: Colors.red,
      mouseDown: Colors.red.dark,
      iconNormal: theme.inactiveColor,
      iconMouseOver: Colors.red.basedOnLuminance(),
      iconMouseDown: Colors.red.dark.basedOnLuminance(),
    );
    return Row(children: [
      Tooltip(
        message: FluentLocalizations.of(context).minimizeWindowTooltip,
        child: MinimizeWindowButton(colors: buttonColors),
      ),
      Tooltip(
        message: FluentLocalizations.of(context).restoreWindowTooltip,
        child: WindowButton(
          colors: buttonColors,
          iconBuilder: (context) {
            if (appWindow.isMaximized) {
              return RestoreIcon(color: context.iconColor);
            }
            return MaximizeIcon(color: context.iconColor);
          },
          onPressed: appWindow.maximizeOrRestore,
        ),
      ),
      Tooltip(
        message: FluentLocalizations.of(context).closeWindowTooltip,
        child: CloseWindowButton(colors: closeButtonColors),
      ),
    ]);
  }
}

==> win32_gamepad-1.0.6.tar.gz: example/inspector/lib/custom_window.dart <==
// Copyright (c) 2023, Dart | Windows. Please see the AUTHORS file for details.
// All rights reserved. Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

import 'package:bitsdojo_window/bitsdojo_window.dart';
import 'package:fluent_ui/fluent_ui.dart';

class CustomWindowTitleSection extends StatelessWidget {
  const CustomWindowTitleSection({super.key, required this.appTitle});

  final String appTitle;

  @override
  Widget build(BuildContext context) {
    return MoveWindow(
      child: Align(
        alignment: AlignmentDirectional.centerStart,
        child: Text(appTitle),
      ),
    );
  }
}

class CustomWindowButtonsSection extends StatelessWidget {
  const CustomWindowButtonsSection({super.key});

  @override
  Widget build(BuildContext context) {
    return MoveWindow(
      child: const Row(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [Spacer(), WindowButtons()],
      ),
    );
  }
}

class WindowButtons extends StatelessWidget {
  const WindowButtons({super.key});

  @override
  Widget build(BuildContext context) {
    assert(debugCheckHasFluentTheme(context));
    assert(debugCheckHasFluentLocalizations(context));
    final theme = FluentTheme.of(context);
    final buttonColors = WindowButtonColors(
      iconNormal: theme.inactiveColor,
      iconMouseDown: theme.inactiveColor,
      iconMouseOver: theme.inactiveColor,
      mouseOver: ButtonThemeData.buttonColor(context, {ButtonStates.hovering}),
      mouseDown: ButtonThemeData.buttonColor(context, {ButtonStates.pressing}),
    );
    final closeButtonColors = WindowButtonColors(
      mouseOver: Colors.red,
      mouseDown: Colors.red.dark,
      iconNormal: theme.inactiveColor,
      iconMouseOver: Colors.red.basedOnLuminance(),
      iconMouseDown: Colors.red.dark.basedOnLuminance(),
    );
    return Row(
      children: [
        Tooltip(
          message: FluentLocalizations.of(context).minimizeWindowTooltip,
          child: MinimizeWindowButton(colors: buttonColors),
        ),
        Tooltip(
          message: FluentLocalizations.of(context).restoreWindowTooltip,
          child: WindowButton(
            colors: buttonColors,
            iconBuilder: (context) => appWindow.isMaximized
                ? RestoreIcon(color: context.iconColor)
                : MaximizeIcon(color: context.iconColor),
            onPressed: appWindow.maximizeOrRestore,
          ),
        ),
        Tooltip(
          message: FluentLocalizations.of(context).closeWindowTooltip,
          child: CloseWindowButton(colors: closeButtonColors),
        ),
      ],
    );
  }
}
